# chrono - agendas system
# Copyright (C) 2016  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf.urls import url

from . import views

urlpatterns = [
    url(r'^$', views.homepage, name='chrono-manager-homepage'),
    url(r'^agendas/add/$', views.agenda_add, name='chrono-manager-agenda-add'),
    url(r'^agendas/import/$', views.agendas_import, name='chrono-manager-agendas-import'),
    url(r'^agendas/(?P<pk>\d+)/$', views.agenda_view, name='chrono-manager-agenda-view'),
    url(
        r'^agendas/(?P<pk>\d+)/(?P<year>[0-9]{4})/(?P<month>[0-9]+)/$',
        views.agenda_monthly_view,
        name='chrono-manager-agenda-month-view',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/(?P<year>[0-9]{4})/(?P<month>[0-9]+)/(?P<day>[0-9]+)/$',
        views.agenda_day_view,
        name='chrono-manager-agenda-day-view',
    ),
    url(r'^agendas/(?P<pk>\d+)/settings$', views.agenda_settings, name='chrono-manager-agenda-settings'),
    url(r'^agendas/(?P<pk>\d+)/edit$', views.agenda_edit, name='chrono-manager-agenda-edit'),
    url(r'^agendas/(?P<pk>\d+)/delete$', views.agenda_delete, name='chrono-manager-agenda-delete'),
    url(r'^agendas/(?P<pk>\d+)/export$', views.agenda_export, name='chrono-manager-agenda-export'),
    url(r'^agendas/(?P<pk>\d+)/add-event$', views.agenda_add_event, name='chrono-manager-agenda-add-event'),
    url(
        r'^agendas/(?P<pk>\d+)/import-events$',
        views.agenda_import_events,
        name='chrono-manager-agenda-import-events',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/events/(?P<event_pk>\d+)/$',
        views.event_view,
        name='chrono-manager-event-view',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/events/(?P<event_pk>\d+)/edit$',
        views.event_edit,
        name='chrono-manager-event-edit',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/events/(?P<event_pk>\d+)/delete$',
        views.event_delete,
        name='chrono-manager-event-delete',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/add-meeting-type$',
        views.agenda_add_meeting_type,
        name='chrono-manager-agenda-add-meeting-type',
    ),
    url(r'^meetingtypes/(?P<pk>\d+)/edit$', views.meeting_type_edit, name='chrono-manager-meeting-type-edit'),
    url(
        r'^meetingtypes/(?P<pk>\d+)/delete$',
        views.meeting_type_delete,
        name='chrono-manager-meeting-type-delete',
    ),
    url(
        r'^agendas/(?P<agenda_pk>\d+)/desk/(?P<pk>\d+)/add-time-period$',
        views.agenda_add_time_period,
        name='chrono-manager-agenda-add-time-period',
    ),
    url(r'^timeperiods/(?P<pk>\d+)/edit$', views.time_period_edit, name='chrono-manager-time-period-edit'),
    url(
        r'^timeperiods/(?P<pk>\d+)/delete$',
        views.time_period_delete,
        name='chrono-manager-time-period-delete',
    ),
    url(r'^agendas/(?P<pk>\d+)/add-desk$', views.agenda_add_desk, name='chrono-manager-agenda-add-desk'),
    url(r'^desks/(?P<pk>\d+)/edit$', views.desk_edit, name='chrono-manager-desk-edit'),
    url(r'^desks/(?P<pk>\d+)/delete$', views.desk_delete, name='chrono-manager-desk-delete'),
    url(
        r'^agendas/(?P<agenda_pk>\d+)/desk/(?P<pk>\d+)/add-time-period-exception$',
        views.agenda_add_time_period_exception,
        name='chrono-manager-agenda-add-time-period-exception',
    ),
    url(
        r'^agendas/desk/(?P<pk>\d+)/import-exceptions-from-ics/$',
        views.desk_import_time_period_exceptions,
        name='chrono-manager-desk-add-import-time-period-exceptions',
    ),
    url(
        r'^time-period-exceptions/(?P<pk>\d+)/edit$',
        views.time_period_exception_edit,
        name='chrono-manager-time-period-exception-edit',
    ),
    url(
        r'^time-period-exceptions/(?P<pk>\d+)/delete$',
        views.time_period_exception_delete,
        name='chrono-manager-time-period-exception-delete',
    ),
    url(
        r'^time-period-exceptions/(?P<pk>\d+)/exception-extract-list$',
        views.time_period_exception_extract_list,
        name='chrono-manager-time-period-exception-extract-list',
    ),
    url(
        r'^time-period-exceptions/(?P<pk>\d+)/exception-list$',
        views.time_period_exception_list,
        name='chrono-manager-time-period-exception-list',
    ),
    url(
        r'^time-period-exceptions-source/(?P<pk>\d+)/delete$',
        views.time_period_exception_source_delete,
        name='chrono-manager-time-period-exception-source-delete',
    ),
    url(
        r'^time-period-exceptions-source/(?P<pk>\d+)/refresh$',
        views.time_period_exception_source_refresh,
        name='chrono-manager-time-period-exception-source-refresh',
    ),
    url(
        r'^time-period-exceptions-source/(?P<pk>\d+)/replace$',
        views.time_period_exception_source_replace,
        name='chrono-manager-time-period-exception-source-replace',
    ),
    url(
        r'^agendas/events.csv$',
        views.agenda_import_events_sample_csv,
        name='chrono-manager-sample-events-csv',
    ),
    url(r'^menu.json$', views.menu_json),
]
